//* -------------------------------------------------------------------------------------------------- *//
//*                                                                                                    *//
//* This class "autocolors" the background of an Index-field with the colors of the Tooltips           *//
//* Purpose: A more intuitive User-Interface where you can see better in which fields you can          *//
//* navigate (F7, F8, F9 ....)                                                                         *//
//*                                                                                                    *//
//* Example for the dbForm Class and the dbGrid Class,                                                 *//
//* but you can integrate it in every other DEO Class                                                  *//
//*                                                                                                    *//
//* Property: Auto_Color_State True|False (if you don't want to automatically color a certain DEO)     *//
//*                                                                                                    *//
//* Author: Peter Bosch                                                                                *//
//*         info trans Logistik Systems GmbH                                                           *//
//*         Rienlgasse 15/3                                                                          *//
//*         A-1040 Wien                                                                                *//
//*         Austria                                                                                    *//
//*         Phone:  +43 1 587 98 45                                                                    *//
//*         Fax:    +43 1 587 24 59                                                                    *//
//*         Mail:   pbosch@infotrans.at                                                                *//
//* Changes and IDE-Support:                                                                           *//
//*         Arnold Franken                                                                             *//
//*         Wildkamp B.V.                                                                              *//
//*         Mail: Franken@Wildkamp.nl                                                                  *//
//*                                                                                                    *//
//* -------------------------------------------------------------------------------------------------- *//
//* Date        Description                                                                            *//
//* 24/01/2000  Color_Grid_Index_Mixin - by changing fields in a grid with mutiple files, you get an   *//
//*             error by changing fields from different files. Changed Get Data_File and Get           *//
//              Data_Field with Item option.                                                           *//
//* 25/01/2000  Color_Form_Index_Mixin - if you are in an indexfield and press F7 or F8 until you run- *//
//*             running out of filo, you will get error 6047 and 6048. By moving the lines "If (Auto_  *//
//*             Color_State..." and "If (Object_Shadow_State..." this problem is solved.               *//
//* -------------------------------------------------------------------------------------------------- *//

// Class for dbForm based DEOs //
Class Color_Form_Index_Mixin is a Message
    Procedure Define_Color_Form_Index_Mixin
        Property Integer Auto_Color_State Public True
    End_Procedure

    Procedure Color_Form_Index_Fields
        Local Integer Srvr Hasindex File# Field#

        If (Auto_Color_State(Self) eq 0) Procedure_Return
        If (Object_Shadow_State(Self) eq 1) Procedure_Return

        Get Server To Srvr
        If Srvr eq 0 Procedure_Return

        Get Data_File Item 0 To File#
        Get Data_Field Item 0 To Field#

        Move (File#>0 And Field_Main_Index(Srvr,File#,Field#)>-1) To Hasindex
        If Hasindex Begin
            Set Color     To clInfoBk                                    // Colors of Tooltips
            Set TextColor To clInfoText                                  // Change this if you want your own colors
        End
    End_Procedure

    Procedure Shadow_Display
        Forward Send Shadow_Display
        Send Color_Form_Index_Fields
        Send Create_Prompt_Button PB_PromptAuto
    End_Procedure

    Procedure Activating
        Send Color_Form_Index_Fields
        Forward Send Activating
    End_Procedure
End_Class

// Class for dbGrid or dbList based DEOs //
Class Color_Grid_Index_Mixin is a Message
    Procedure Define_Color_Grid_Index_Mixin
        Property Integer Auto_Color_State Public True
        Set Highlight_Row_State to False  // maybe with Autocoloring you don't want the current row to be colored with the default colors
    End_Procedure

    Procedure Color_Grid_Index_Fields Integer EntryItem# Integer Item#
        Local Integer Srvr Hasindex File# Field#

        If (Auto_Color_State(Self) eq 0) Procedure_Return

        Get Server To Srvr
        If Srvr eq 0 Procedure_Return

        Get Data_File  Item EntryItem# To File#
        Get Data_Field Item EntryItem# To Field#

        Move (File#>0 And Field_Main_Index(Srvr,File#,Field#)>-1) To Hasindex
        If Hasindex Begin
            Set Item_Color      Item Item# To clInfoBk                      // Colors of Tooltips
            Set ItemTextColor   Item Item# To clInfoText                    // Change this if you want your own colors
        End
    End_Procedure

    Procedure Entry_Display Integer file# Integer disp#
        Integer Base Items I
        If (Auto_Color_State(Self)) Begin
            Get Base_Item   to Base
            Get Item_Limit  to Items
            For I From 0 to (Items - 1)
                Send Color_Grid_Index_Fields I (Base + I)
            Loop
        End
        Forward Send Entry_Display file# disp#
    End_Procedure
End_Class



Class cWikadbForm is a dbForm
    Procedure Construct_Object
        Forward Send Construct_Object
        Send Define_Color_Form_Index_Mixin
    End_Procedure

    Import_Class_Protocol Color_Form_Index_Mixin
End_Class

Class cWikadbGrid is a dbGrid
    Procedure Construct_Object
        Forward Send Construct_Object
        Send Define_Color_Grid_Index_Mixin
    End_Procedure

    Import_Class_Protocol Color_Grid_Index_Mixin
End_Class